@@ -1,16 +1,4 @@
 #!/usr/bin/python3
-"""
-
-    ###################
-    ##               ##
-    ##    Pi-Clap    ##
-    ##               ##
-    ###################
-
-Repo: https://github.com/nikhiljohn10/pi-clap
-Author: Nikhil John
-License: MIT
-"""
 
 from array import array
 
